#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.gth"), aligned (8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[2992]; const double alignment; void * const ptr;}  gth_resource_data = { {
  0x47, 0x56, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x18, 0x00, 0x00, 0x00, 0x1c, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x28, 0x09, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x03, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 
  0x06, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 
  0x08, 0x00, 0x00, 0x00, 0x4b, 0x50, 0x90, 0x0b, 
  0x04, 0x00, 0x00, 0x00, 0x1c, 0x01, 0x00, 0x00, 
  0x04, 0x00, 0x4c, 0x00, 0x20, 0x01, 0x00, 0x00, 
  0x24, 0x01, 0x00, 0x00, 0xfe, 0x97, 0xe1, 0xb3, 
  0x07, 0x00, 0x00, 0x00, 0x24, 0x01, 0x00, 0x00, 
  0x0a, 0x00, 0x4c, 0x00, 0x30, 0x01, 0x00, 0x00, 
  0x34, 0x01, 0x00, 0x00, 0xb0, 0xb7, 0x24, 0x30, 
  0x00, 0x00, 0x00, 0x00, 0x34, 0x01, 0x00, 0x00, 
  0x06, 0x00, 0x4c, 0x00, 0x3c, 0x01, 0x00, 0x00, 
  0x40, 0x01, 0x00, 0x00, 0x69, 0x78, 0x63, 0x4c, 
  0x05, 0x00, 0x00, 0x00, 0x40, 0x01, 0x00, 0x00, 
  0x0c, 0x00, 0x76, 0x00, 0x50, 0x01, 0x00, 0x00, 
  0x5f, 0x09, 0x00, 0x00, 0xd4, 0xb5, 0x02, 0x00, 
  0xff, 0xff, 0xff, 0xff, 0x5f, 0x09, 0x00, 0x00, 
  0x01, 0x00, 0x4c, 0x00, 0x60, 0x09, 0x00, 0x00, 
  0x64, 0x09, 0x00, 0x00, 0x14, 0x5a, 0x16, 0x89, 
  0x08, 0x00, 0x00, 0x00, 0x64, 0x09, 0x00, 0x00, 
  0x03, 0x00, 0x4c, 0x00, 0x68, 0x09, 0x00, 0x00, 
  0x70, 0x09, 0x00, 0x00, 0x8b, 0x47, 0xdb, 0x0c, 
  0x05, 0x00, 0x00, 0x00, 0x70, 0x09, 0x00, 0x00, 
  0x11, 0x00, 0x76, 0x00, 0x88, 0x09, 0x00, 0x00, 
  0x97, 0x0b, 0x00, 0x00, 0x66, 0xf1, 0x4e, 0x60, 
  0x02, 0x00, 0x00, 0x00, 0x97, 0x0b, 0x00, 0x00, 
  0x07, 0x00, 0x4c, 0x00, 0xa0, 0x0b, 0x00, 0x00, 
  0xa4, 0x0b, 0x00, 0x00, 0x07, 0x04, 0x3f, 0xdb, 
  0x01, 0x00, 0x00, 0x00, 0xa4, 0x0b, 0x00, 0x00, 
  0x05, 0x00, 0x4c, 0x00, 0xac, 0x0b, 0x00, 0x00, 
  0xb0, 0x0b, 0x00, 0x00, 0x6f, 0x72, 0x67, 0x2f, 
  0x02, 0x00, 0x00, 0x00, 0x62, 0x6f, 0x6f, 0x6b, 
  0x6d, 0x61, 0x72, 0x6b, 0x73, 0x2f, 0x00, 0x00, 
  0x08, 0x00, 0x00, 0x00, 0x67, 0x6e, 0x6f, 0x6d, 
  0x65, 0x2f, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 
  0x62, 0x6f, 0x6f, 0x6b, 0x6d, 0x61, 0x72, 0x6b, 
  0x73, 0x2e, 0x75, 0x69, 0x00, 0x00, 0x00, 0x00, 
  0x0f, 0x34, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xed, 0x5b, 0xdb, 0x92, 0xe2, 0x36, 
  0x10, 0x7d, 0xdf, 0xaf, 0x50, 0xf4, 0x9a, 0xf2, 
  0x82, 0x99, 0xdb, 0x66, 0x0a, 0xbc, 0x95, 0xad, 
  0x64, 0x27, 0x0f, 0x9b, 0x7d, 0x48, 0x26, 0xc9, 
  0xa3, 0x4b, 0xd8, 0x3d, 0x58, 0x8b, 0x2c, 0x39, 
  0x92, 0x60, 0x86, 0xfc, 0x44, 0x1e, 0xf3, 0x7f, 
  0xf9, 0x92, 0xc8, 0x36, 0x30, 0x5c, 0xe4, 0x3b, 
  0x73, 0x61, 0x43, 0xd5, 0x50, 0x35, 0x18, 0x75, 
  0x4b, 0x7d, 0xac, 0x3e, 0x3a, 0xdd, 0x86, 0xe1, 
  0xfb, 0x87, 0x98, 0xa1, 0x39, 0x48, 0x45, 0x05, 
  0x1f, 0x61, 0xf7, 0x6d, 0x1f, 0x23, 0xe0, 0x81, 
  0x08, 0x29, 0x9f, 0x8c, 0xf0, 0x6f, 0xb7, 0x1f, 
  0x9d, 0x77, 0xf8, 0xbd, 0xf7, 0x66, 0xf8, 0x8d, 
  0xe3, 0xa0, 0x1b, 0xe0, 0x20, 0x89, 0x86, 0x10, 
  0xdd, 0x53, 0x1d, 0xa1, 0x09, 0x23, 0x21, 0xa0, 
  0xb3, 0xb7, 0xee, 0xe5, 0xdb, 0x3e, 0x12, 0x1c, 
  0xfd, 0x6c, 0x5e, 0x9f, 0xc5, 0x1c, 0xb9, 0x2e, 
  0xea, 0x7f, 0x77, 0xed, 0x5e, 0x5e, 0x0f, 0xde, 
  0xa1, 0x41, 0xdf, 0x3d, 0x43, 0x8e, 0x63, 0x1c, 
  0x50, 0xae, 0x41, 0xde, 0x91, 0x00, 0xbc, 0x37, 
  0x08, 0x65, 0xee, 0xd6, 0x57, 0x1c, 0x09, 0x7f, 
  0xce, 0xa8, 0x04, 0x85, 0x26, 0x7a, 0xfa, 0x6d, 
  0xea, 0xb1, 0x9f, 0xd9, 0x98, 0x71, 0x62, 0xfc, 
  0x05, 0x02, 0x8d, 0x02, 0x46, 0x94, 0x1a, 0xe1, 
  0x1b, 0x3d, 0xfd, 0x81, 0x12, 0x26, 0x26, 0x18, 
  0xd1, 0x70, 0x84, 0xc7, 0x42, 0x4c, 0x63, 0x22, 
  0xa7, 0xca, 0x0f, 0xf3, 0xab, 0xa9, 0x89, 0x31, 
  0x4a, 0xa4, 0x48, 0x40, 0xea, 0x05, 0xe2, 0x24, 
  0x86, 0x11, 0x8e, 0x80, 0x4e, 0x22, 0xed, 0xa7, 
  0x93, 0x80, 0xd2, 0xd8, 0x3b, 0xef, 0xf7, 0x87, 
  0xbd, 0xd5, 0x18, 0xbb, 0x49, 0x40, 0xb8, 0x7f, 
  0x27, 0x82, 0x99, 0xc2, 0xde, 0x47, 0xc2, 0x14, 
  0x54, 0x8d, 0x1f, 0x0b, 0x19, 0x82, 0xf4, 0xef, 
  0x69, 0xa8, 0x23, 0xec, 0x5d, 0x54, 0x0d, 0xd7, 
  0x54, 0x33, 0xc0, 0x48, 0x4b, 0xc2, 0x15, 0x23, 
  0x9a, 0x8c, 0x99, 0xb9, 0xb8, 0x00, 0x33, 0xdb, 
  0x87, 0x55, 0x48, 0x95, 0x2e, 0x16, 0x09, 0xf8, 
  0x91, 0x81, 0x10, 0x7b, 0x79, 0xf0, 0x7b, 0x06, 
  0x41, 0x44, 0x59, 0x98, 0x83, 0xcc, 0x09, 0x73, 
  0xb2, 0xb7, 0x23, 0x3c, 0x1f, 0x8b, 0x87, 0x25, 
  0x4e, 0x36, 0x78, 0x3f, 0x98, 0x4f, 0x33, 0x6c, 
  0x73, 0xa7, 0x4e, 0x3a, 0xfc, 0x6a, 0x3d, 0x7e, 
  0x7f, 0x19, 0x73, 0xaa, 0xa8, 0x59, 0x3d, 0xf6, 
  0x6e, 0xe5, 0x6c, 0x0f, 0xa5, 0x36, 0xc8, 0xda, 
  0x6c, 0x84, 0xa4, 0xc0, 0x35, 0xd1, 0x66, 0x87, 
  0x62, 0xcf, 0x6c, 0x55, 0x4d, 0x03, 0xc2, 0xac, 
  0x86, 0xf6, 0x98, 0x49, 0x90, 0x9a, 0xfa, 0x44, 
  0x02, 0xd9, 0x08, 0xc5, 0x1a, 0xfe, 0x4c, 0x6b, 
  0xc1, 0x77, 0x41, 0xd8, 0xb0, 0xbf, 0xda, 0x72, 
  0xd0, 0x02, 0x8f, 0xb6, 0x98, 0xd8, 0xec, 0x18, 
  0x59, 0x88, 0x99, 0xf6, 0x95, 0x5e, 0xa4, 0x33, 
  0x02, 0x0f, 0x0b, 0x0d, 0x33, 0x20, 0xb6, 0xaf, 
  0x15, 0x87, 0xbf, 0x4c, 0xae, 0xd8, 0x0f, 0x98, 
  0x50, 0xe0, 0x8f, 0xf3, 0x8b, 0xbb, 0xd6, 0xb6, 
  0xe5, 0x8c, 0x81, 0x61, 0xcf, 0xe4, 0xb0, 0x93, 
  0x59, 0x16, 0xad, 0xa6, 0x35, 0x6e, 0x15, 0xd8, 
  0x35, 0x35, 0x95, 0x10, 0x00, 0x9d, 0x83, 0x61, 
  0x0f, 0xb8, 0x23, 0x33, 0xa6, 0x9b, 0x7b, 0x98, 
  0x19, 0x78, 0x94, 0x16, 0xc1, 0xb4, 0xca, 0x74, 
  0xd8, 0xcb, 0xb1, 0xde, 0xbb, 0x9e, 0x90, 0x60, 
  0x6a, 0x98, 0xb6, 0x7a, 0x2a, 0x78, 0x48, 0x08, 
  0x0f, 0x2b, 0x36, 0x88, 0xcd, 0xf0, 0x8e, 0x32, 
  0xd6, 0xc2, 0x2c, 0x11, 0x8a, 0xe6, 0x09, 0x37, 
  0x28, 0x0b, 0xcb, 0xba, 0xfe, 0x61, 0x6f, 0x6f, 
  0xbf, 0xd9, 0x00, 0xb0, 0x07, 0xdf, 0x2a, 0x70, 
  0x7b, 0xd0, 0x4d, 0x72, 0x30, 0x5d, 0x8b, 0x9f, 
  0x92, 0x6a, 0x79, 0x22, 0x15, 0xa2, 0xd4, 0xb7, 
  0x9b, 0x58, 0x10, 0xda, 0x43, 0x67, 0x3f, 0x3b, 
  0xf7, 0x33, 0xf3, 0xa7, 0x35, 0x27, 0x45, 0x86, 
  0x91, 0x2f, 0x5e, 0x15, 0x0d, 0x6d, 0x1f, 0x7e, 
  0x97, 0x75, 0xcd, 0x94, 0x41, 0xc6, 0x00, 0x63, 
  0x36, 0xd8, 0x79, 0x57, 0xde, 0xfa, 0x7d, 0x8d, 
  0x4e, 0x7a, 0x5e, 0x9d, 0x5f, 0xe1, 0xe7, 0x21, 
  0x9c, 0xc6, 0x49, 0xb5, 0x0e, 0xf9, 0xb2, 0xd4, 
  0xca, 0x1a, 0xb5, 0x3d, 0xf2, 0x4f, 0x19, 0xe7, 
  0xae, 0x08, 0xfb, 0x51, 0x10, 0x2d, 0xb9, 0xd8, 
  0xe2, 0xa3, 0x03, 0x14, 0x5d, 0xe1, 0xb0, 0xd9, 
  0x3f, 0x10, 0x46, 0x27, 0xc5, 0xf9, 0x53, 0x75, 
  0xda, 0xd8, 0x34, 0x94, 0xbf, 0x16, 0x51, 0xd7, 
  0x4d, 0x9d, 0xa6, 0x84, 0x3e, 0xe3, 0x66, 0x37, 
  0x33, 0xca, 0x6b, 0x01, 0x52, 0x44, 0xec, 0xe5, 
  0xe4, 0xde, 0x89, 0xe0, 0x3b, 0x90, 0x7c, 0x2b, 
  0x0a, 0xab, 0x20, 0xfb, 0x02, 0xc2, 0x6f, 0xbe, 
  0x95, 0xd7, 0x39, 0x6c, 0x52, 0xd8, 0x3d, 0x86, 
  0xad, 0x5b, 0x5b, 0x96, 0xd6, 0x43, 0xc4, 0x8e, 
  0xca, 0xaf, 0x81, 0x14, 0x8c, 0x41, 0xf8, 0x07, 
  0xe5, 0xa1, 0xb8, 0x5f, 0x67, 0x3a, 0xa3, 0x4a, 
  0xfb, 0x81, 0x30, 0xd3, 0x9b, 0x8d, 0x2a, 0x71, 
  0x91, 0xbf, 0xfd, 0x45, 0x67, 0x2c, 0xfd, 0x58, 
  0x0b, 0x0d, 0x2e, 0x2a, 0x13, 0xaf, 0x33, 0xee, 
  0x1d, 0x65, 0x5b, 0xe1, 0x1a, 0x56, 0x19, 0xd3, 
  0xd6, 0xc1, 0x7d, 0x06, 0xa9, 0x9f, 0x30, 0x53, 
  0x82, 0xc6, 0x90, 0x56, 0x52, 0x63, 0x61, 0xa4, 
  0x6e, 0xec, 0x30, 0xb8, 0xd3, 0x6d, 0x1c, 0xaa, 
  0x88, 0xa4, 0x0e, 0x97, 0x2a, 0x42, 0x07, 0x11, 
  0x84, 0x0e, 0xe5, 0xb5, 0x3c, 0x95, 0xee, 0x8a, 
  0x7c, 0xae, 0x74, 0x99, 0x91, 0x60, 0x86, 0x9c, 
  0x7a, 0x25, 0x8e, 0x7a, 0xe5, 0xfb, 0xab, 0x84, 
  0xae, 0xaa, 0x29, 0xab, 0x8c, 0xb6, 0xda, 0xde, 
  0x84, 0x6a, 0xa5, 0x76, 0x10, 0xf2, 0xaa, 0x20, 
  0xb0, 0x4a, 0xe8, 0x9a, 0xa6, 0xed, 0xad, 0x10, 
  0x6c, 0x4c, 0x64, 0x9e, 0xaf, 0x3a, 0x7f, 0xe3, 
  0xe2, 0x97, 0x49, 0xb0, 0x5a, 0xe4, 0x96, 0xf9, 
  0xc8, 0x2a, 0xc9, 0xd2, 0x5d, 0x98, 0x45, 0xb8, 
  0x9c, 0x82, 0xf2, 0xf4, 0x94, 0x74, 0x96, 0xd1, 
  0xe1, 0xd2, 0x5d, 0x59, 0xe1, 0x79, 0x77, 0xf5, 
  0xd4, 0x50, 0x9b, 0xaf, 0xe8, 0x5f, 0x50, 0x5a, 
  0x7e, 0x34, 0xca, 0x1f, 0xeb, 0x2d, 0xda, 0x29, 
  0x78, 0x27, 0xc2, 0xd7, 0xa2, 0xb8, 0xe0, 0x3d, 
  0xe8, 0x0d, 0x3b, 0xd4, 0x4d, 0xb3, 0x36, 0x87, 
  0x4c, 0x68, 0x9a, 0x26, 0xbe, 0x86, 0x07, 0x6d, 
  0x95, 0x48, 0x37, 0x02, 0x69, 0xf3, 0x17, 0x51, 
  0x85, 0x98, 0x08, 0xb2, 0x23, 0xac, 0xed, 0x5c, 
  0x8d, 0x25, 0x53, 0xc5, 0x5d, 0x4f, 0xff, 0xc5, 
  0xde, 0x44, 0x38, 0x5f, 0x66, 0x71, 0xe2, 0xa8, 
  0x45, 0x3c, 0x16, 0x8c, 0x06, 0xf5, 0x5c, 0x56, 
  0xd1, 0x5b, 0x3d, 0x8a, 0xeb, 0xac, 0xce, 0x8a, 
  0x9c, 0x44, 0x22, 0x16, 0x13, 0xe0, 0x20, 0x9a, 
  0x1c, 0x7b, 0x95, 0xbc, 0x55, 0x83, 0xf6, 0x0f, 
  0x96, 0x20, 0x12, 0x62, 0x31, 0x87, 0xff, 0x43, 
  0x86, 0xfc, 0x92, 0x45, 0xfa, 0xba, 0x92, 0x02, 
  0x42, 0xaa, 0x9d, 0x10, 0x18, 0x68, 0x38, 0x25, 
  0xc6, 0x41, 0x12, 0xe3, 0xe9, 0xf4, 0x50, 0xfd, 
  0x43, 0xf7, 0x89, 0x04, 0x91, 0xfb, 0x94, 0x82, 
  0xe8, 0xf0, 0x65, 0x6f, 0x9b, 0x02, 0xae, 0x3e, 
  0x54, 0xad, 0x61, 0x6a, 0x5e, 0xf4, 0x1e, 0xae, 
  0xd5, 0xdb, 0xb4, 0x33, 0x55, 0x0f, 0x8e, 0x56, 
  0x12, 0xba, 0x7e, 0xa3, 0xb7, 0x6d, 0xd3, 0xce, 
  0x7d, 0xf5, 0x3d, 0x3b, 0x77, 0x70, 0xa8, 0xa6, 
  0xdd, 0x76, 0xe4, 0x83, 0x63, 0xe8, 0x75, 0xd4, 
  0xeb, 0x5c, 0xb6, 0xa9, 0x94, 0x36, 0x3a, 0x98, 
  0x59, 0x4b, 0xef, 0xf5, 0x57, 0x49, 0x6d, 0x3b, 
  0x98, 0x0d, 0xbb, 0x98, 0x9f, 0xcd, 0x80, 0x36, 
  0x2e, 0x5b, 0x6a, 0x8f, 0x5d, 0x37, 0x31, 0x37, 
  0x0a, 0x88, 0xd3, 0x20, 0xed, 0xeb, 0x4f, 0x40, 
  0xa7, 0x8f, 0x45, 0xb4, 0x5c, 0x64, 0x4a, 0xa4, 
  0x96, 0x3b, 0xa2, 0xb5, 0xa4, 0x46, 0x28, 0x82, 
  0x2a, 0x3d, 0xc2, 0xd7, 0xc3, 0x56, 0x4d, 0x99, 
  0xec, 0x61, 0x3d, 0x46, 0x73, 0xc2, 0x66, 0xd9, 
  0xb3, 0x05, 0x16, 0x96, 0x57, 0x96, 0xd5, 0xf3, 
  0x7c, 0xc5, 0x87, 0xfc, 0x2b, 0xeb, 0x7a, 0x7c, 
  0x9f, 0x66, 0x42, 0xd6, 0x4a, 0xcb, 0xf2, 0x99, 
  0xac, 0xde, 0x1e, 0x5d, 0x4e, 0xa7, 0x1d, 0x40, 
  0x3f, 0x21, 0x61, 0x58, 0x83, 0xf9, 0xbb, 0x94, 
  0x58, 0x3f, 0xa6, 0x39, 0x95, 0x83, 0xf5, 0x98, 
  0x5e, 0x2f, 0x5c, 0x57, 0x75, 0x2a, 0x56, 0xf8, 
  0x72, 0x35, 0x7e, 0x10, 0x11, 0x89, 0xbd, 0x7f, 
  0xff, 0xf9, 0xbb, 0xad, 0xab, 0xbc, 0x51, 0x9d, 
  0xba, 0x31, 0x6b, 0x3a, 0xeb, 0x1f, 0xaa, 0xce, 
  0x39, 0xd6, 0x82, 0xa0, 0xb5, 0xf9, 0xd1, 0x56, 
  0x04, 0x1d, 0x1e, 0x84, 0x75, 0x2b, 0x09, 0x5e, 
  0xf8, 0x39, 0xd8, 0xb6, 0x3a, 0x3c, 0x3b, 0xa9, 
  0xc3, 0x4d, 0x75, 0x38, 0x38, 0xa9, 0xc3, 0x5c, 
  0x1d, 0x7e, 0x6a, 0xd0, 0xb6, 0x7d, 0x5e, 0x85, 
  0xd8, 0xa4, 0xa1, 0x7c, 0x52, 0x89, 0xcf, 0xc2, 
  0xfc, 0x47, 0x22, 0x13, 0x07, 0x27, 0x99, 0x58, 
  0x53, 0x26, 0xae, 0x72, 0xec, 0x24, 0x15, 0x4f, 
  0x52, 0xf1, 0x24, 0x15, 0x5f, 0x4e, 0x2a, 0x9e, 
  0xba, 0xc7, 0x75, 0xa0, 0xf8, 0x9a, 0xbe, 0x26, 
  0x5c, 0x15, 0x6f, 0xf5, 0x17, 0x7e, 0xb7, 0x63, 
  0xdc, 0xfa, 0x70, 0x98, 0xff, 0xd2, 0xc0, 0xc9, 
  0x05, 0xd5, 0x5a, 0xaa, 0x6c, 0x5f, 0x46, 0x12, 
  0x54, 0x22, 0xb8, 0x32, 0xab, 0xe9, 0x63, 0x6f, 
  0xe7, 0x6b, 0xfa, 0x46, 0xe9, 0x6c, 0x8e, 0x5d, 
  0xcd, 0xb1, 0xef, 0xf7, 0x71, 0x15, 0xc3, 0xde, 
  0xc6, 0x4f, 0x73, 0xfe, 0x03, 0x70, 0x68, 0xe8, 
  0x5e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x2f, 
  0x00, 0x00, 0x00, 0x00, 0x75, 0x69, 0x2f, 0x00, 
  0x06, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x62, 0x6f, 0x6f, 0x6b, 0x6d, 0x61, 0x72, 0x6b, 
  0x73, 0x2d, 0x6d, 0x65, 0x6e, 0x75, 0x2e, 0x75, 
  0x69, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x0b, 0x03, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xa5, 0x92, 0x4b, 0x4e, 0xc3, 0x30, 
  0x10, 0x86, 0xf7, 0x3d, 0x85, 0xeb, 0x2d, 0x72, 
  0x52, 0xc4, 0xd6, 0x71, 0x15, 0x0a, 0x27, 0x80, 
  0x5d, 0x55, 0x21, 0x27, 0x1e, 0x2a, 0x2b, 0x8e, 
  0x03, 0xf6, 0x04, 0xc8, 0x8e, 0xd3, 0x70, 0x30, 
  0x4e, 0x82, 0x9b, 0x50, 0xa7, 0xa1, 0x88, 0x87, 
  0xba, 0x9c, 0xe7, 0xff, 0xcd, 0x83, 0x2f, 0x5f, 
  0x6a, 0x43, 0x9e, 0xc0, 0x79, 0xdd, 0xd8, 0x8c, 
  0x9e, 0x27, 0x0b, 0xba, 0x14, 0x33, 0xae, 0x2d, 
  0x82, 0xbb, 0x97, 0x25, 0x88, 0x19, 0x21, 0x7c, 
  0xce, 0x18, 0x89, 0x1e, 0xe6, 0xe0, 0xb1, 0xd5, 
  0x0e, 0x3c, 0xd9, 0x62, 0x75, 0x46, 0x2e, 0x92, 
  0x05, 0x61, 0xac, 0x4f, 0xab, 0xc1, 0xb6, 0x44, 
  0xab, 0x8c, 0x16, 0x4d, 0x53, 0xd5, 0xd2, 0x55, 
  0x9e, 0xed, 0x5c, 0x74, 0x17, 0x0c, 0x61, 0x0f, 
  0x25, 0x06, 0x91, 0xc1, 0x0a, 0xb6, 0x46, 0xa8, 
  0xf7, 0x46, 0x30, 0x25, 0xa2, 0xd3, 0x45, 0x8b, 
  0x40, 0xac, 0xac, 0x21, 0xa3, 0x46, 0x16, 0x60, 
  0x28, 0x41, 0x27, 0xad, 0x37, 0x12, 0x65, 0x61, 
  0x82, 0xb3, 0x03, 0x4f, 0xc5, 0x5d, 0xae, 0x14, 
  0xb9, 0xfc, 0xd4, 0xe0, 0x69, 0x2c, 0xfc, 0xa1, 
  0x99, 0xec, 0xa5, 0xa9, 0x78, 0xd6, 0x36, 0x19, 
  0xe9, 0xa4, 0x52, 0xdf, 0x94, 0xf3, 0xf4, 0x90, 
  0xec, 0x04, 0xcc, 0x6b, 0xa5, 0x31, 0x72, 0xfa, 
  0xf7, 0xd7, 0xb7, 0x53, 0x58, 0x21, 0x34, 0xfb, 
  0x6b, 0x7d, 0x19, 0x88, 0x04, 0x9f, 0xaf, 0x57, 
  0x57, 0xf9, 0x6d, 0xbe, 0xe6, 0x2b, 0x74, 0x46, 
  0x14, 0x9b, 0x8d, 0xf8, 0x65, 0x58, 0x9e, 0x4e, 
  0x4e, 0xc4, 0x7d, 0x5b, 0xc4, 0x93, 0xfa, 0xce, 
  0x87, 0x3c, 0x16, 0x79, 0x68, 0x6c, 0xf0, 0x8f, 
  0x85, 0xdc, 0xf4, 0x4d, 0xc6, 0x95, 0x1c, 0xf1, 
  0x04, 0x82, 0x41, 0x73, 0xfa, 0x32, 0x3d, 0x01, 
  0x58, 0x74, 0x1d, 0x7b, 0x68, 0xc2, 0x23, 0xee, 
  0xd5, 0x8f, 0x80, 0x0f, 0xd2, 0xbf, 0x92, 0x4e, 
  0x72, 0x79, 0x3a, 0x88, 0x84, 0xe9, 0xc7, 0x47, 
  0xff, 0x00, 0xe9, 0x60, 0xf7, 0xea, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x67, 
  0x54, 0x68, 0x75, 0x6d, 0x62, 0x2f, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00, 0x64, 0x61, 0x74, 0x61, 
  0x2f, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00
} };

static GStaticResource static_resource = { gth_resource_data.data, sizeof (gth_resource_data.data), NULL, NULL, NULL };
extern GResource *gth_get_resource (void);
GResource *gth_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a sane way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
